@@ -336,214 +336,94 @@ journal7 = nulljournal {jtxns =
           [
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/01/01",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="opening balance",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="assets:cash",
-                pamount=(Mixed [usd 4.82]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="equity:opening balances",
-                pamount=(Mixed [usd (-4.82)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["assets:cash" `post` usd 4.82
+                 ,"equity:opening balances" `post` usd (-4.82)
+                 ],
              tpreceding_comment_lines=""
            }
           ,
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/02/01",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="ayres suites",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="expenses:vacation",
-                pamount=(Mixed [usd 179.92]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="assets:checking",
-                pamount=(Mixed [usd (-179.92)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["expenses:vacation" `post` usd 179.92
+                 ,"assets:checking" `post` usd (-179.92)
+                 ],
              tpreceding_comment_lines=""
            }
           ,
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/01/02",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="auto transfer to savings",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="assets:saving",
-                pamount=(Mixed [usd 200]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="assets:checking",
-                pamount=(Mixed [usd (-200)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["assets:saving" `post` usd 200
+                 ,"assets:checking" `post` usd (-200)
+                 ],
              tpreceding_comment_lines=""
            }
           ,
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/01/03",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="poquito mas",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="expenses:food:dining",
-                pamount=(Mixed [usd 4.82]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="assets:cash",
-                pamount=(Mixed [usd (-4.82)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["expenses:food:dining" `post` usd 4.82
+                 ,"assets:cash" `post` usd (-4.82)
+                 ],
              tpreceding_comment_lines=""
            }
           ,
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/01/03",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="verizon",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="expenses:phone",
-                pamount=(Mixed [usd 95.11]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="assets:checking",
-                pamount=(Mixed [usd (-95.11)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["expenses:phone" `post` usd 95.11
+                 ,"assets:checking" `post` usd (-95.11)
+                 ],
              tpreceding_comment_lines=""
            }
           ,
            txnTieKnot $ Transaction {
              tdate=parsedate "2007/01/03",
-             teffectivedate=Nothing,
+             tdate2=Nothing,
              tstatus=False,
              tcode="*",
              tdescription="discover",
              tcomment="",
              ttags=[],
-             tpostings=[
-              Posting {
-                pstatus=False,
-                paccount="liabilities:credit cards:discover",
-                pamount=(Mixed [usd 80]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              },
-              Posting {
-                pstatus=False,
-                paccount="assets:checking",
-                pamount=(Mixed [usd (-80)]),
-                pcomment="",
-                ptype=RegularPosting,
-                ptags=[],
-                ptransaction=Nothing
-              }
-             ],
+             tpostings=
+                 ["liabilities:credit cards:discover" `post` usd 80
+                 ,"assets:checking" `post` usd (-80)
+                 ],
              tpreceding_comment_lines=""
            }
           ]
          }
 
 ledger7 = ledgerFromJournal Any journal7
-
--- journal8_str = unlines
---  ["2008/1/1 test           "
---  ,"  a:b          10h @ $40"
---  ,"  c:d                   "
---  ,""
---  ]
-
--- timelogentry1_str  = "i 2007/03/11 16:19:00 hledger\n"
--- timelogentry1 = TimeLogEntry In (parsedatetime "2007/03/11 16:19:00") "hledger"
-
--- timelogentry2_str  = "o 2007/03/11 16:30:00\n"
--- timelogentry2 = TimeLogEntry Out (parsedatetime "2007/03/11 16:30:00") ""
-
--- a1 = Mixed [(hrs 1){aprice=Just $ Mixed [Amount (comm "$") 10 Nothing]}]
--- a2 = Mixed [(hrs 2){aprice=Just $ Mixed [Amount (comm "EUR") 10 Nothing]}]
--- a3 = Mixed $ amounts a1 ++ amounts a2
-
--- journalWithAmounts :: [String] -> Journal
--- journalWithAmounts as =
---        nulljournal{jtxns=
---         [t | a <- as, let t = nulltransaction{tdescription=a,tpostings=[nullposting{pamount=parse a,ptransaction=Just t}]}]
---         }
---     where parse = fromparse . parseWithCtx nullctx amountp
