@@ -10,7 +10,6 @@ module Hledger.Cli.Version (
   binaryfilename
 )
 where
-import Distribution.PackageDescription.TH (packageVariable, package, pkgName, pkgVersion)
 import System.Info (os, arch)
 import Text.Printf
 
@@ -19,12 +18,11 @@ import Hledger.Utils
 
 -- package name and version from the cabal file
 progname, version, prognameandversion :: String
-#if HADDOCK
-progname = ""
-version  = ""
+progname = "hledger"
+#ifdef VERSION
+version = VERSION
 #else
-progname = $(packageVariable (pkgName . package))
-version  = $(packageVariable (pkgVersion . package))
+version = ""
 #endif
 prognameandversion = progname ++ " " ++ version
 
@@ -57,7 +55,7 @@ binaryfilename progname = prettify $ splitAtElement '.' buildversion
                                 | patches/="0" = '+' : patches
                                 | otherwise = ""
                             (os',suffix)
-                                | os == "darwin"  = ("mac","")
+                                | os == "darwin"  = ("mac","" :: String)
                                 | os == "mingw32" = ("windows",".exe")
                                 | otherwise       = (os,"")
                   prettify (major:minor:bugfix:[]) = prettify [major,minor,bugfix,"0"]
